import {
  select,
  csv,
  pie,
  arc,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';

const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');

// dollors symbol is added
const numberFormat = number =>
  	(Math.abs(Number(number))) + " $" ;

//describing the pie chart data 
const render = data => {
  const pieData = pie().sort(null).value(d=>d.cost_of_living_in_100$_permonth)(data);
  const colors = scaleOrdinal(schemeCategory10);
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(200)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.cost_of_living_in_100$_permonth))
  	.on("mouseover", d => console.log(d.data.cost_of_living_in_100$_permonth));
  //piechart is created 
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  // list of each country as labels and its styles

  legend.append("rect").attr("width",22).attr("height",25)
  	.attr("fill", d => colors(d.data.cost_of_living_in_100$_permonth));
  legend.append("text")
  	.attr("x", 28)
  	.attr("y", 18)
  	.attr("class","legend_text")
  	.text(d => d.data.country);
  legend.append("text")
  	.attr("x", 260)
  	.attr("y", 20)
  	.attr("class","legend_value")
  	.text(d=>numberFormat(d.data.cost_of_living_in_100$_permonth*100));
  //multiply with 100 as 100 times of our column gives the amount in dollars
}

// url of my data 

const csvUrl =
 'https://gist.githubusercontent.com/MekaNavyasri/67abe671ee928ff495b0315176ecd189/raw/ef1b46f8f29e18f1aa675e486eb300fd45731b76/ICE7_piechart';


//Load the data and display the top 10,cost of living of countries
csv(csvUrl).then(csvData => {
    csvData.sort((data1, data2) => data2.cost_of_living_in_100$_permonth-data1.cost_of_living_in_100$_permonth);
    if (csvData) {
      render(csvData.slice(0, 10));
    }
});